import HttpClient from '@nextcloud/axios'
import * as types from '../mutation-types'
import { linkTo } from '@nextcloud/router'
import { showError, showSuccess } from '@nextcloud/dialogs'

// state
export const state = {
	apikey: null,
	regUrl: null,
}

// getters
export const getters = {
	apikey: state => state.apikey,
	regUrl: state => state.regUrl,
}

// mutations
export const mutations = {
	[types.APIKEY_SET](state, data) {
		state.apikey = data.apikey
		state.regUrl = data.regUrl
	},
}

// actions
export const actions = {

	async getApikey({ commit }) {
		try {
			const response = await HttpClient.get(linkTo('vibeetoee', 'index.php') + '/api/v1/setup/apikey', {
				headers: { Accept: 'application/json' },
			})

			const res = response.data.ocs
			if (res.meta.status === 'ok') {
				commit(types.APIKEY_SET, res.data)
			}
			return true

		} catch (e) {
			console.error(e)
			throw e
		}
	},

	async storeApikey({ commit, state }, key) {
		try {
			const response = await HttpClient.post(linkTo('vibeetoee', 'index.php') + '/api/v1/setup/apikey', { apikey: key }, {
				headers: {
					Accept: 'application/json',
				},
			})

			const res = response.data.ocs

			if (res.meta.status === 'ok') {
				commit(types.APIKEY_SET, {
					apikey: res.data.apikey,
					regUrl: state.regUrl,
				})
				showSuccess(t('vibeetoee', 'Success'), { timeout: 5000 })

			} else if (res.meta.status === 'failure') {
				showError(t('vibeetoee', 'Error') + ': ' + res.meta.message, { timeout: 5000 })
			}

			return true

		} catch (e) {
			console.error(e)
			throw e
		}
	},
}
